@@ -24,10 +24,12 @@ type Job struct {
 	SpuriousErrorCounter int
 	Total                int
 	Running              bool
+	RunningJob           bool
 	Count403             int
 	Count429             int
 	Error                string
 	startTime            time.Time
+	startTimeJob         time.Time
 	queuejobs            []QueueJob
 	queuepos             int
 	currentDepth         int
@@ -44,6 +46,7 @@ func NewJob(conf *Config) Job {
 	j.ErrorCounter = 0
 	j.SpuriousErrorCounter = 0
 	j.Running = false
+	j.RunningJob = false
 	j.queuepos = 0
 	j.queuejobs = make([]QueueJob, 0)
 	j.currentDepth = 0
@@ -81,12 +84,18 @@ func (j *Job) resetSpuriousErrors() {
 
 //Start the execution of the Job
 func (j *Job) Start() {
+	if j.startTime.IsZero() {
+		j.startTime = time.Now()
+	}
+
 	// Add the default job to job queue
 	j.queuejobs = append(j.queuejobs, QueueJob{Url: j.Config.Url, depth: 0})
 	rand.Seed(time.Now().UnixNano())
 	j.Total = j.Input.Total()
 	defer j.Stop()
+
 	j.Running = true
+	j.RunningJob = true
 	//Show banner if not running in silent mode
 	if !j.Config.Quiet {
 		j.Output.Banner()
@@ -95,12 +104,14 @@ func (j *Job) Start() {
 	j.interruptMonitor()
 	for j.jobsInQueue() {
 		j.prepareQueueJob()
-		if j.queuepos > 1 {
+
+		if j.queuepos > 1 && !j.RunningJob {
 			// Print info for queued recursive jobs
 			j.Output.Info(fmt.Sprintf("Scanning: %s", j.Config.Url))
 		}
 		j.Input.Reset()
-		j.startTime = time.Now()
+		j.startTimeJob = time.Now()
+		j.RunningJob = true
 		j.Counter = 0
 		j.startExecution()
 	}
@@ -127,13 +138,16 @@ func (j *Job) startExecution() {
 	go j.runProgress(&wg)
 	//Limiter blocks after reaching the buffer, ensuring limited concurrency
 	limiter := make(chan bool, j.Config.Threads)
+
 	for j.Input.Next() {
 		// Check if we should stop the process
 		j.CheckStop()
+
 		if !j.Running {
 			defer j.Output.Warning(j.Error)
 			break
 		}
+
 		limiter <- true
 		nextInput := j.Input.Value()
 		nextPosition := j.Input.Position()
@@ -154,6 +168,11 @@ func (j *Job) startExecution() {
 				time.Sleep(sleepDurationMS * time.Millisecond)
 			}
 		}()
+
+		if !j.RunningJob {
+			defer j.Output.Warning(j.Error)
+			return
+		}
 	}
 	wg.Wait()
 	j.updateProgress()
@@ -175,20 +194,27 @@ func (j *Job) runProgress(wg *sync.WaitGroup) {
 	defer wg.Done()
 	totalProgress := j.Input.Total()
 	for j.Counter <= totalProgress {
+
 		if !j.Running {
 			break
 		}
+
 		j.updateProgress()
 		if j.Counter == totalProgress {
 			return
 		}
+
+		if !j.RunningJob {
+			return
+		}
+
 		time.Sleep(time.Millisecond * time.Duration(j.Config.ProgressFrequency))
 	}
 }
 
 func (j *Job) updateProgress() {
 	prog := Progress{
-		StartedAt:  j.startTime,
+		StartedAt:  j.startTimeJob,
 		ReqCount:   j.Counter,
 		ReqTotal:   j.Input.Total(),
 		QueuePos:   j.queuepos,
@@ -305,6 +331,7 @@ func (j *Job) handleRecursionJob(resp Response) {
 //CalibrateResponses returns slice of Responses for randomly generated filter autocalibration requests
 func (j *Job) CalibrateResponses() ([]Response, error) {
 	cInputs := make([]string, 0)
+	rand.Seed(time.Now().UnixNano())
 	if len(j.Config.AutoCalibrationStrings) < 1 {
 		cInputs = append(cInputs, "admin"+RandomString(16)+"/")
 		cInputs = append(cInputs, ".htaccess"+RandomString(16))
@@ -367,15 +394,26 @@ func (j *Job) CheckStop() {
 		}
 	}
 
-	// check for maximum running time
+	// Check for runtime of entire process
 	if j.Config.MaxTime > 0 {
 		dur := time.Now().Sub(j.startTime)
 		runningSecs := int(dur / time.Second)
 		if runningSecs >= j.Config.MaxTime {
-			j.Error = "Maximum running time reached, exiting."
+			j.Error = "Maximum running time for entire process reached, exiting."
 			j.Stop()
 		}
 	}
+
+	// Check for runtime of current job
+	if j.Config.MaxTimeJob > 0 {
+		dur := time.Now().Sub(j.startTimeJob)
+		runningSecs := int(dur / time.Second)
+		if runningSecs >= j.Config.MaxTimeJob {
+			j.Error = "Maximum running time for this job reached, continuing with next job if one exists."
+			j.Next()
+
+		}
+	}
 }
 
 //Stop the execution of the Job
@@ -383,3 +421,9 @@ func (j *Job) Stop() {
 	j.Running = false
 	return
 }
+
+//Stop current, resume to next
+func (j *Job) Next() {
+	j.RunningJob = false
+	return
+}
